==> Acme-MetaSyntactic-Themes-1.001.tar.gz: Acme-MetaSyntactic-Themes-1.001/lib/Acme/MetaSyntactic/magic8ball.pm <==
package Acme::MetaSyntactic::magic8ball;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::magic8ball - The magic8ball theme

=head1 DESCRIPTION

The legendary fortune-telling toy, in yet another computer
programmed incarnation, this time using Acme::MetaSyntactic!

This metasyntactic Magic 8 Ball may be nice, even useful for
important choices in your life, but be sure to ask the Public
8 Ball as well: L<http://8ball.federated.com/>.

The Magic 8 Ball answers list can be found here
L<http://www.fiendation.com/people/chris/eight.htm> and here
L<http://www.brtb.com/articles/magic8index.shtml> and here
L<http://8ball.ofb.net/answers.html>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in Acme-MetaSyntactic version 0.19, published on April 25, 2005.

Corrected (4 items were missing) in version 0.24, published on May 30, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
As_I_See_It_Yes
Ask_Again_Later
Better_Not_Tell_You_Now
Cannot_Predict_Now
Concentrate_and_Ask_Again
Don_t_Count_On_It
It_Is_Certain
It_Is_Decidedly_So
Most_Likely
My_Reply_Is_No
My_Sources_Say_No
Outlook_Good
Outlook_Not_So_Good
Reply_Hazy_Try_Again
Signs_Point_to_Yes
Very_Doubtful
Without_a_Doubt
Yes
Yes_Definitely
You_May_Rely_On_It

==> Acme-MetaSyntactic-Themes-1.047.tar.gz: Acme-MetaSyntactic-Themes-1.047/lib/Acme/MetaSyntactic/magic8ball.pm <==
package Acme::MetaSyntactic::magic8ball;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::magic8ball - The magic8ball theme

=head1 DESCRIPTION

The legendary fortune-telling toy, in yet another computer
programmed incarnation, this time using Acme::MetaSyntactic!

This metasyntactic Magic 8 Ball may be nice, even useful for
important choices in your life, but be sure to ask the Public
8 Ball as well: L<http://8ball.federated.com/>.

The Magic 8 Ball answers list can be found here
L<http://www.fiendation.com/people/chris/eight.htm> and here
L<http://www.brtb.com/articles/magic8index.shtml> and here
L<http://8ball.ofb.net/answers.html>.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-05-30

Corrected (4 items were missing)
in Acme-MetaSyntactic version 0.24.

=item *

2005-04-25

Introduced in Acme-MetaSyntactic version 0.19.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
As_I_See_It_Yes
Ask_Again_Later
Better_Not_Tell_You_Now
Cannot_Predict_Now
Concentrate_and_Ask_Again
Don_t_Count_On_It
It_Is_Certain
It_Is_Decidedly_So
Most_Likely
My_Reply_Is_No
My_Sources_Say_No
Outlook_Good
Outlook_Not_So_Good
Reply_Hazy_Try_Again
Signs_Point_to_Yes
Very_Doubtful
Without_a_Doubt
Yes
Yes_Definitely
You_May_Rely_On_It
